@@ -13,7 +13,7 @@
 
 #include <sendmail.h>
 
-SM_RCSID("@(#)$Id: collect.c,v 8.242.2.2 2002/08/16 14:56:01 ca Exp $")
+SM_RCSID("@(#)$Id: collect.c,v 8.242.2.3 2002/12/03 17:06:30 gshapiro Exp $")
 
 static void	collecttimeout __P((time_t));
 static void	dferror __P((SM_FILE_T *volatile, char *, ENVELOPE *));
@@ -350,6 +350,16 @@ collect(fp, smtpmode, hdrp, e)
 					  "timeout waiting for input from %s during message collect",
 					  CURHOSTNAME);
 			errno = 0;
+			if (smtpmode)
+			{
+				/*
+				**  Override e_message in usrerr() as this
+				**  is the reason for failure that should
+				**  be logged for undelivered recipients.
+				*/
+
+				e->e_message = NULL;
+			}
 			usrerr("451 4.4.1 timeout waiting for input during message collect");
 			goto readerr;
 		}
