@@ -15,7 +15,7 @@
 #include <sm/debug.h>
 #include <sm/string.h>
 
-SM_RCSID("@(#)$Id: trace.c,v 8.37 2001/09/11 04:05:17 gshapiro Exp $")
+SM_RCSID("@(#)$Id: trace.c,v 8.37.4.1 2002/12/05 17:28:05 ca Exp $")
 
 static char	*tTnewflag __P((char *));
 static char	*tToldflag __P((char *));
@@ -204,7 +204,7 @@ void
 tTflag(s)
 	register char *s;
 {
-	if (*s == '\0')
+	if (s == NULL || *s == '\0')
 		s = DefFlags;
 
 	for (;;)
